@@ -1,4 +1,4 @@
 vcov.netlm <- function(object, ...) {
-  so <- summary.lm(object, corr = FALSE, ...)
+  so <- summary.lm(object, correlation = FALSE, ...)
   so$sigma^2 * so$cov.unscaled
 }
