@@ -1,5 +1,5 @@
 vcov.logit.net <- function(object, ...)
 {
-    so <- summary.glm(object, corr=FALSE, ...)
+    so <- summary.glm(object, correlation=FALSE, ...)
     so$dispersion * so$cov.unscaled
-}
\ No newline at end of file
+}
