@@ -1290,7 +1290,3 @@ return(res)
 ### > dim(zmatNA) = 38  6
 
 
-## file is soruced when R CMD build Zelig
-
-zideal <- create.zelig.all.packages("Zelig")
-save(zideal, file="inst/zideal/zideal.RData")
